==> codat-common-0.18.1.tar.gz: codat-common-0.18.1/README.md <==
# codat-common

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-common
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatcommon
from codatcommon.models import shared

s = codatcommon.CodatCommon(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)

req = shared.CompanyRequestBody(
    description='Requested early access to the new financing scheme.',
    name='Bank of Dave',
)

res = s.companies.create(req)

if res.company is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [companies](docs/companies/README.md)

* [create](docs/companies/README.md#create) - Create company
* [delete](docs/companies/README.md#delete) - Delete a company
* [get](docs/companies/README.md#get) - Get company
* [list](docs/companies/README.md#list) - List companies
* [update](docs/companies/README.md#update) - Update company

### [connections](docs/connections/README.md)

* [create](docs/connections/README.md#create) - Create connection
* [delete](docs/connections/README.md#delete) - Delete connection
* [get](docs/connections/README.md#get) - Get connection
* [list](docs/connections/README.md#list) - List connections
* [unlink_connection](docs/connections/README.md#unlink_connection) - Unlink connection
* [update_authorization](docs/connections/README.md#update_authorization) - Update authorization

### [data_status](docs/datastatus/README.md)

* [get](docs/datastatus/README.md#get) - Get data status
* [get_pull_operation](docs/datastatus/README.md#get_pull_operation) - Get pull operation
* [list_pull_operations](docs/datastatus/README.md#list_pull_operations) - Get pull operations

### [integrations](docs/integrations/README.md)

* [get](docs/integrations/README.md#get) - Get integration
* [get_branding](docs/integrations/README.md#get_branding) - Get branding
* [list](docs/integrations/README.md#list) - List integrations

### [push_data](docs/pushdata/README.md)

* [get_model_options](docs/pushdata/README.md#get_model_options) - Get push options
* [get_operation](docs/pushdata/README.md#get_operation) - Get push operation
* [list_operations](docs/pushdata/README.md#list_operations) - List push operations

### [refresh_data](docs/refreshdata/README.md)

* [all](docs/refreshdata/README.md#all) - Queue pull operations
* [by_data_type](docs/refreshdata/README.md#by_data_type) - Queue pull operation

### [settings](docs/settings/README.md)

* [~~get_profile~~](docs/settings/README.md#get_profile) - Get profile :warning: **Deprecated**
* [get_sync_settings](docs/settings/README.md#get_sync_settings) - Update all sync settings
* [update_profile](docs/settings/README.md#update_profile) - Update profile

### [webhooks](docs/webhooks/README.md)

* [create](docs/webhooks/README.md#create) - Create webhook
* [get](docs/webhooks/README.md#get) - Get webhook
* [list](docs/webhooks/README.md#list) - List webhooks
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)

==> codat-common-0.20.1.tar.gz: codat-common-0.20.1/README.md <==
# codat-common

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-common
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatcommon
from codatcommon.models import shared

s = codatcommon.CodatCommon(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)

req = shared.CompanyRequestBody(
    description='Requested early access to the new financing scheme.',
    name='Bank of Dave',
)

res = s.companies.create(req)

if res.company is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [companies](docs/companies/README.md)

* [create](docs/companies/README.md#create) - Create company
* [delete](docs/companies/README.md#delete) - Delete a company
* [get](docs/companies/README.md#get) - Get company
* [list](docs/companies/README.md#list) - List companies
* [update](docs/companies/README.md#update) - Update company

### [connections](docs/connections/README.md)

* [create](docs/connections/README.md#create) - Create connection
* [delete](docs/connections/README.md#delete) - Delete connection
* [get](docs/connections/README.md#get) - Get connection
* [list](docs/connections/README.md#list) - List connections
* [unlink_connection](docs/connections/README.md#unlink_connection) - Unlink connection
* [update_authorization](docs/connections/README.md#update_authorization) - Update authorization

### [integrations](docs/integrations/README.md)

* [get](docs/integrations/README.md#get) - Get integration
* [get_branding](docs/integrations/README.md#get_branding) - Get branding
* [list](docs/integrations/README.md#list) - List integrations

### [push_data](docs/pushdata/README.md)

* [get_model_options](docs/pushdata/README.md#get_model_options) - Get push options
* [get_operation](docs/pushdata/README.md#get_operation) - Get push operation
* [list_operations](docs/pushdata/README.md#list_operations) - List push operations

### [refresh_data](docs/refreshdata/README.md)

* [all](docs/refreshdata/README.md#all) - Refresh all data
* [by_data_type](docs/refreshdata/README.md#by_data_type) - Refresh data type
* [get](docs/refreshdata/README.md#get) - Get data status
* [get_pull_operation](docs/refreshdata/README.md#get_pull_operation) - Get pull operation
* [list_pull_operations](docs/refreshdata/README.md#list_pull_operations) - List pull operations

### [settings](docs/settings/README.md)

* [~~get_profile~~](docs/settings/README.md#get_profile) - Get profile :warning: **Deprecated**
* [get_sync_settings](docs/settings/README.md#get_sync_settings) - Update all sync settings
* [update_profile](docs/settings/README.md#update_profile) - Update profile

### [webhooks](docs/webhooks/README.md)

* [create](docs/webhooks/README.md#create) - Create webhook
* [get](docs/webhooks/README.md#get) - Get webhook
* [list](docs/webhooks/README.md#list) - List webhooks
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
